==> nextcloud-16.0.9.tar.bz2: nextcloud/apps/privacy/l10n/ru.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Конфиденциальность",
    "-" : "—",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центр конфиденциальности показывает вам, где хранятся ваши данные и кто может получить к ним доступ: администраторы и те, с кем вы поделились этими данными.",
    "Remove external admin" : "Удалить внешнего администратора",
    "Add external admin" : "Добавить внешнего администратора",
    "Your files are not protected by encryption." : "Ваши файлы не защищены шифрованием.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Для защиты ваших файлов используется {linkopen}шифрование на стороне сервера ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Этот сервер защищён шифрованием диска.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Для защиты ваших файлов используется {linkopen}шифрование на стороне сервера ↗{linkclose}. Также этот сервер защищён с помощью шифрования диска.",
    "This server is using full-disk-encryption." : "Этот сервер использует шифрование диска.",
    "Change data location" : "Изменить расположение данных",
    "Your data is located in: " : "Размещение данных:",
    "The admin hasn't selected the location of the server yet." : "Место размещения сервера ещё не указано администратором.",
    "Please select a country" : "Выберите страну",
    "You don't have any shares with individual users." : "У вас нет общего доступа с отдельными пользователями.",
    "Somaliland" : "Сомалиленд",
    "United Arab Emirates" : "Объединенные Арабские Эмираты",
    "Afghanistan" : "Афганистан",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Argentina" : "Аргентина",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegowina" : "Босния и Герцеговина",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельгия",
    "Burkina Faso" : "Буркина-Фасо",
    "Bulgaria" : "Болгария",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Brunei" : "Бруней",
    "Bolivia" : "Боливия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Багамские острова",
    "Bhutan" : "Бутан",
    "Botswana" : "Ботсвана",
    "Belarus" : "Беларусь",
    "Belize" : "Белиз",
    "Canada" : "Канада",
    "Democratic Republic of the Congo" : "Демократическая Республика Конго",
    "Central African Republic" : "Центральная Африканская Республика",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Cote d'Ivoire" : "Кот-д’Ивуар",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста-Рика",
    "Cuba" : "Куба",
    "Cyprus" : "Кипр",
    "Czech" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominican Republic" : "Доминиканская Республика",
    "Algeria" : "Алжир",
    "Ecuador" : "Эквадор",
    "Estonia" : "Эстония",
    "Egypt" : "Египет",
    "West Sahara" : "Западная Сахара",
    "Eritrea" : "Эритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Эфиопия",
    "Finland" : "Финляндия",
    "Fiji" : "Фиджи",
    "Falkland Islands" : "Фолклендские острова",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom" : "Великобритания",
    "Georgia" : "Грузия",
    "Ghana" : "Гана",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Equatorial Guinea" : "Экваториальная Гвинея",
    "Greece" : "Греция",
    "Guatemala" : "Гватемала",
    "Guinea-Bissau" : "Гвинея-Биссау",
    "Guyana" : "Гайана",
    "Honduras" : "Гондурас",
    "Croatia" : "Хорватия",
    "Haiti" : "Гаити",
    "Hungary" : "Венгрия",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израиль",
    "India" : "Индия",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jamaica" : "Ямайка",
    "Jordan" : "Иордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизия",
    "Cambodia" : "Камбожда",
    "North Korea" : "Корейская Народно-Демократическая Республика",
    "South Korea" : "Республика Корея",
    "Kuwait" : "Кувейт",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Королевство Лаос",
    "Lebanon" : "Ливан",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Ливия",
    "Morocco" : "Марокко",
    "Moldova" : "Молдавия",
    "Montenegro" : "Черногория",
    "Madagascar" : "Мадагаскар",
    "Macedonia" : "Северная Македония",
    "Mali" : "Мали",
    "Myanmar" : "Мьянма",
    "Mongolia" : "Монголия",
    "Mauritania" : "Мавритания",
    "Malawi" : "Малави",
    "Mexico" : "Мексика",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Новая Каледония",
    "Niger" : "Нигер",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерланды",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "New Zealand" : "Новая Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "Papua New Guinea" : "Папуа Новая Гвинея",
    "Philippines" : "Филипинны",
    "Pakistan" : "Пакистан",
    "Poland" : "Польша",
    "Puerto Rico" : "Пуэрто Рико",
    "Portugal" : "Португалия",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Romania" : "Румыния",
    "Serbia" : "Сербия",
    "Russia" : "Россия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудовская Аравия",
    "Solomon Islands" : "Соломоновы Острова",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Slovenia" : "Словения",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сьерра Леоне",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомали",
    "Suriname" : "Суринам",
    "South Sudan" : "Южный Судан",
    "El Salvador" : "Эль-Сальвадор",
    "Syria" : "Сирия",
    "Swaziland" : "Свазиленд",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Французские Южные и Антарктические территории",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Timor-Leste" : "Восточный Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Taiwan" : "Тайвань",
    "Tanzania" : "Танзания",
    "Ukraine" : "Украина",
    "Uganda" : "Уганда",
    "United States" : "Соединённые Штаты Америки",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Venezuela" : "Венесуэла",
    "Vietnam" : "Вьетнам",
    "Vanuatu" : "Вануату",
    "Yemen" : "Йемен",
    "South Africa" : "Южная Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Your Nextcloud account" : "Ваша учётная запись Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ваши данные дают представление о том, кто их владелец, и могут быть использованы в корыстных целях. Мы в Nextcloud уверены, что вы вправе решать, что будет происходить с вашими данными. Nextcloud защищает ваши права в соответствии с Манифестом пользовательских данных!",
    "User Data Manifesto 2.0" : "Манифест пользовательских данных 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Определяет основное право людей контролировать собственные данные в эпоху Интернета",
    "Control" : "Контроль",
    "over user data access" : "за доступом к своим данным",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Пользовательские данные должны быть под полным контролем пользователя. Люди сами в состоянии решить, кому и как предоставлять прямой доступ к своим данным и с какими разрешениями и лицензиями такой доступ может быть предоставлен.",
    "Knowledge" : "Осведомленность",
    "of how the data is stored" : "о том, как хранятся данные пользователя",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Когда пользовательские данные загружены к конкретному поставщику услуг, пользователи должны быть проинформированы о географическом расположении такого провайдера, обрабатывающего эти данные, в течение какого времени эти данные будут у него находится и в какой юрисдикции, какие законы будут применяться по отношению хранения пользовательских данных.",
    "Freedom" : "Свобода",
    "to choose a platform" : "в выборе платформы",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Люди всегда должны иметь возможность извлечь свои данные от поставщика услуг, в любое время, вне зависимости от выбора вендора. Чтобы это гарантировать, необходимы открытые стандарты для форматов и протоколов.",
    "Learn more ↗" : "Дополнительная информация ↗",
    "Where is your data?" : "Где хранятся ваши данные?",
    "Who has access to your data?" : "У кого есть доступ к вашим данным?",
    "Administrators" : "Администраторы",
    "People you shared with" : "Люди, с которыми вы поделились",
    "Privacy policy" : "Политика конфиденциальности",
    "Read the privacy policy." : "Ознакомиться с политикой конфиденциальности.",
    "Encryption" : "Шифрование"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-21.0.0.tar.bz2: nextcloud/apps/privacy/l10n/ru.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Конфиденциальность",
    "-" : "—",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центр конфиденциальности показывает вам, где хранятся ваши данные и кто может получить к ним доступ: администраторы и те, с кем вы поделились этими данными.",
    "Remove external admin" : "Удалить внешнего администратора",
    "Add external admin" : "Добавить внешнего администратора",
    "Name of external admin" : "Имя внешнего администратора",
    "This server is using full-disk-encryption." : "Этот сервер использует шифрование диска.",
    "Your files are not protected by encryption." : "Ваши файлы не защищены шифрованием.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Для защиты ваших файлов используется {linkopen}шифрование на стороне сервера ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Этот сервер защищён шифрованием диска.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Для защиты ваших файлов используется {linkopen}шифрование на стороне сервера ↗{linkclose}. Также этот сервер защищён с помощью шифрования диска.",
    "Your data is located in: " : "Размещение данных:",
    "The admin hasn't selected the location of the server yet." : "Место размещения сервера ещё не указано администратором.",
    "Change data location" : "Изменить расположение данных",
    "Please select a region" : "Пожалуйста, выберите регион",
    "You don't have any shares with individual users." : "У вас нет общего доступа с отдельными пользователями.",
    "Somaliland" : "Сомалиленд",
    "Andorra" : "Андорра",
    "United Arab Emirates" : "Объединенные Арабские Эмираты",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангилья",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктика",
    "Argentina" : "Аргентина",
    "American Samoa" : "Американское Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Аландские острова",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босния и Герцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельгия",
    "Burkina Faso" : "Буркина-Фасо",
    "Bulgaria" : "Болгария",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен-Бартелеми",
    "Bermuda" : "Бермудские Острова",
    "Brunei" : "Бруней",
    "Bolivia" : "Боливия",
    "Bonaire, Sint Eustatius and Saba" : "Бонэйр, Синт-Эстатиус и Саба",
    "Brazil" : "Бразилия",
    "Bahamas" : "Багамские острова",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Остров Буве",
    "Botswana" : "Ботсвана",
    "Belarus" : "Беларусь",
    "Belize" : "Белиз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосовые (Килинг) острова",
    "Democratic Republic of the Congo" : "Демократическая Республика Конго",
    "Central African Republic" : "Центральная Африканская Республика",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Cote d'Ivoire" : "Кот-д’Ивуар",
    "Cook Islands" : "Острова Кука",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста-Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо-Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "Остров Рождества",
    "Cyprus" : "Кипр",
    "Czech" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominican Republic" : "Доминиканская Республика",
    "Algeria" : "Алжир",
    "Ecuador" : "Эквадор",
    "Estonia" : "Эстония",
    "Egypt" : "Египет",
    "West Sahara" : "Западная Сахара",
    "Eritrea" : "Эритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Эфиопия",
    "Finland" : "Финляндия",
    "Fiji" : "Фиджи",
    "Falkland Islands" : "Фолклендские острова",
    "Micronesia" : "Микронезия",
    "Faroe Islands" : "Фарерские острова",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom" : "Великобритания",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Французская Гайана",
    "Guernsey" : "Гернси",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Экваториальная Гвинея",
    "Greece" : "Греция",
    "South Georgia and the South Sandwich Islands" : "Южная Георгия и Южные Сандвичевы Острова",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея-Биссау",
    "Guyana" : "Гайана",
    "Honduras" : "Гондурас",
    "Hong Kong" : "Гонконг",
    "Heard Island and McDonald Islands" : "Остров Херд и острова Макдональд",
    "Croatia" : "Хорватия",
    "Haiti" : "Гаити",
    "Hungary" : "Венгрия",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израиль",
    "Isle of Man" : "Остров Мэн",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британская территория Индийского океана",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jamaica" : "Ямайка",
    "Jordan" : "Иордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизия",
    "Cambodia" : "Камбожда",
    "Kiribati" : "Кирибати",
    "Comores" : "Коморы",
    "Saint Kitts and Nevis" : "Сент-Китс и Невис",
    "North Korea" : "Корейская Народно-Демократическая Республика",
    "South Korea" : "Республика Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Каймановы острова",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Королевство Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сент-Люсия",
    "Liechtenstein" : "Лихтенштейн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Ливия",
    "Morocco" : "Марокко",
    "Monaco" : "Монако",
    "Moldova" : "Молдавия",
    "Montenegro" : "Черногория",
    "Saint Martin" : "Сен-Мартен",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалловы Острова",
    "Macedonia" : "Северная Македония",
    "Mali" : "Мали",
    "Myanmar" : "Мьянма",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северные Марианские Острова",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монтсеррат",
    "Malta" : "Мальта",
    "Mauritius" : "Маврикий",
    "Maldives" : "Мальдивы",
    "Malawi" : "Малави",
    "Mexico" : "Мексика",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Новая Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Норфолские Острова",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерланды",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуэ",
    "New Zealand" : "Новая Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Французская Полинезия",
    "Papua New Guinea" : "Папуа Новая Гвинея",
    "Philippines" : "Филипинны",
    "Pakistan" : "Пакистан",
    "Poland" : "Польша",
    "Saint Pierre and Miquelon" : "Сен-Пьер и Микелон",
    "Pitcairn" : "Острова Питкэрн",
    "Puerto Rico" : "Пуэрто Рико",
    "Palestine" : "Палестина",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюньон",
    "Romania" : "Румыния",
    "Serbia" : "Сербия",
    "Russia" : "Россия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудовская Аравия",
    "Solomon Islands" : "Соломоновы Острова",
    "Seychelles" : "Сейшельские Острова",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Острова Святой Елены, Вознесения и Тристан-да-Кунья",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Шпицберген и Ян-Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сьерра Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомали",
    "Suriname" : "Суринам",
    "South Sudan" : "Южный Судан",
    "Sao Tome and Principe" : "Сантоме и Принсипи",
    "El Salvador" : "Эль-Сальвадор",
    "Sint Maarten" : "Синт-Мартен",
    "Syria" : "Сирия",
    "Swaziland" : "Свазиленд",
    "Turks and Caicos Islands" : "Теркс и Кайкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Французские Южные и Антарктические территории",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Восточный Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонганский",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тайвань",
    "Tanzania" : "Танзания",
    "Ukraine" : "Украина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Внешние малые острова США",
    "United States" : "Соединённые Штаты Америки",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Ватикан",
    "Saint Vincent and the Grenadines" : "Сант Винсент и Гренадины",
    "Venezuela" : "Венесуэла",
    "Virgin Islands (British)" : "Британские Вирджинские Острова",
    "Virgin Islands (U.S.)" : "Американские Вирджинские Острова",
    "Vietnam" : "Вьетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уоллис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майотта",
    "South Africa" : "Южная Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Your Nextcloud account" : "Ваша учётная запись Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ваши данные дают представление о том, кто их владелец, и могут быть использованы в корыстных целях. Мы в Nextcloud уверены, что вы вправе решать, что будет происходить с вашими данными. Nextcloud защищает ваши права в соответствии с Манифестом пользовательских данных!",
    "User Data Manifesto 2.0" : "Манифест пользовательских данных 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Определяет основное право людей контролировать собственные данные в эпоху Интернета",
    "Control" : "Контроль",
    "over user data access" : "за доступом к своим данным",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Пользовательские данные должны быть под полным контролем пользователя. Люди сами в состоянии решить, кому и как предоставлять прямой доступ к своим данным и с какими разрешениями и лицензиями такой доступ может быть предоставлен.",
    "Knowledge" : "Осведомленность",
    "of how the data is stored" : "о том, как хранятся данные пользователя",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Когда пользовательские данные загружены к конкретному поставщику услуг, пользователи должны быть проинформированы о географическом расположении такого провайдера, обрабатывающего эти данные, в течение какого времени эти данные будут у него находится и в какой юрисдикции, какие законы будут применяться по отношению хранения пользовательских данных.",
    "Freedom" : "Свобода",
    "to choose a platform" : "в выборе платформы",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Люди всегда должны иметь возможность извлечь свои данные от поставщика услуг, в любое время, вне зависимости от выбора вендора. Чтобы это гарантировать, необходимы открытые стандарты для форматов и протоколов.",
    "Learn more ↗" : "Дополнительная информация ↗",
    "Where is your data?" : "Где хранятся ваши данные?",
    "Who has access to your data?" : "У кого есть доступ к вашим данным?",
    "Administrators" : "Администраторы",
    "People you shared with" : "Люди, с которыми вы поделились",
    "Privacy policy" : "Политика конфиденциальности",
    "Read the privacy policy." : "Ознакомиться с политикой конфиденциальности.",
    "Encryption" : "Шифрование"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
